@@ -18,7 +18,7 @@
 #    along with py-prefork-server.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-__version__ = '0.1.5'
-
-from BaseChild import *
-from Manager import *
+from __version__ import *
+from child import *
+from manager import *
+from exceptions import *
